@@ -307,6 +307,16 @@ class NetworkFirewallPipe(Pipe):
                 self.json_logs.append(log)
 
 
+class AzureActivityPipe(Pipe):
+    def __init__(self):
+        super().__init__()
+
+    def push(self, content):
+        log_data = loads(content)
+        for record in log_data["records"]:
+            self.json_logs.append(record)
+
+
 def DataPipe():
 
     pipe_selector = {
@@ -317,6 +327,7 @@ def DataPipe():
         "aws_s3_access": S3AccessPipe,
         "aws_route53_query": Route53QueryPipe,
         "aws_network_firewall": NetworkFirewallPipe,
+        "azure_test": AzureActivityPipe,
     }
 
     return pipe_selector[get_app_id()]()
